﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="http://www.w3.org/1999/xhtml">
	<xsl:output method="html" indent="yes" version="4.01"
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
		doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>
	<xsl:param name="CSSFile1"></xsl:param>
	<xsl:variable name="MusicDB" select="document('PreMusicVideos.XML')"/>
	<xsl:variable name="AssignHistoryPath">
		<xsl:choose>
			<xsl:when test="//Settings/ForeignGroupMode=1">ForeignAssignHistory.xml</xsl:when>
			<xsl:otherwise>AssignHistory.xml</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="AssignHistory" select="document($AssignHistoryPath)"/>
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<xsl:choose>
				<xsl:when test="//Settings/ForeignGroupMode=1">
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/ForeignGroupLanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/ForeignGroupDirection"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/LanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/Direction"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<head>
				<meta http-equiv="X-UA-Compatible" content="IE=edge" />
				<meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
				<xsl:choose>
					<xsl:when test="$CSSFile1 !=''">
						<style type="text/css">
							<xsl:value-of select="$CSSFile1"/>
						</style>
					</xsl:when>
					<xsl:otherwise>
						<link rel="stylesheet" type="text/css" href="Worksheet-S-140-Weekend Meeting-v2.1.css"/>
					</xsl:otherwise>
				</xsl:choose>
				<title>
					<xsl:text>Weekend Meeting Worksheet</xsl:text>
				</title>
			</head>
			<body>
				<xsl:for-each select="MeetingWorkBook/Meeting/PUBLICTALK">
                    <div class="section">
    					<!--We only add the page breaks when we are in "Print Preview" mode-->
    					<xsl:if test="InsertPageBreak=1">
    						<xsl:call-template name="PageBreak"/>
    					</xsl:if>
    					<div class="content">
    						<h2>
    							<xsl:value-of select="//Labels/PTS_WeekendMeeting"/>
    						</h2>
    						<h3>
    							<xsl:value-of select="MeetingDate/@DayFull"/>
    							<xsl:text>, </xsl:text>
    							<xsl:value-of select="MeetingDate/@Day"/>
    							<xsl:text> </xsl:text>
    							<xsl:value-of select="MeetingDate/@MonthFull"/>
    							<xsl:text> </xsl:text>
    							<xsl:value-of select="MeetingDate/@Year"/>
    						</h3>
    					</div>
    					<table class="table1">
    						<tr>
    							<td class="highlight">
    								<h4>
    									<xsl:text>Pre-music video: </xsl:text>
    									<xsl:variable name="ThisWeek" select="../Date/@ThisWeek"/>
    									<xsl:value-of select="$MusicDB/PreMusicVideos/Video[@Week=$ThisWeek]/Weekend"/>
    									<xsl:text> (</xsl:text>
    									<xsl:value-of select="$MusicDB/PreMusicVideos/Video[@Week=$ThisWeek]/Weekend/@Duration"/>
    									<xsl:text> min.)</xsl:text>
    								</h4>
    							</td>
    						</tr>
    					</table>
					<br />
					<table class="table1">
						<colgroup>
							<col style="width: 30%;"/>
							<col style="width: 60%;"/>
						</colgroup>
						<tr>
							<td>
								<xsl:value-of select="//Labels/VideoConferenceHost"/>
							</td>
							<td>
								<xsl:value-of select="Assignments/VideoConferenceHost"/>
							</td>
						</tr>
						<tr>
							<td>
								<xsl:value-of select="//Labels/VideoConferenceCohost"/>
							</td>
							<td>
								<xsl:value-of select="Assignments/VideoConferenceCohost"/>
							</td>
						</tr>
						<tr>
							<td>
								<xsl:value-of select="//Labels/Chairman"/>
							</td>
							<td>
								<xsl:value-of select="Assignments/Chairman"/>
							</td>
						</tr>

					</table>
                    </div>
                    <div class="section">
    					<div class="content">
    						<h2>
    							<xsl:value-of select="//Labels/PTS_Talk"/>
    						</h2>
    					</div>
    					<table class="table1">
    						<colgroup>
    							<col class="colTime"/>
    							<col class="colLabel"/>
    							<col class="colText"/>
    						</colgroup>
    						<tr>
    							<td>
    								<xsl:value-of select="SongInfo/SongOpen/@StartTime24"/>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/Song"/>
    								<xsl:text>:</xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="SongInfo/SongOpen/@Title"/>
    								<xsl:text> (#</xsl:text>
    								<xsl:value-of select="SongInfo/SongOpen"/>
    								<xsl:text>)</xsl:text>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank first">
    								<xsl:value-of select="HomeTalk/Time/@StartTime24"/>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/PTS_Speaker"/>
    								<xsl:text>:</xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="HomeTalk/Speaker"/>
    								<xsl:text> (</xsl:text>
    								<xsl:value-of select="HomeTalk/Congregation"/>
    								<xsl:text>)</xsl:text>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank">
    								<xsl:text> </xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/PTS_Theme"/>
    								<xsl:text>:</xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="HomeTalk/Theme"/>
    								<xsl:text> (#</xsl:text>
    								<xsl:value-of select="HomeTalk/ThemeNumber"/>
    								<xsl:text>)</xsl:text>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank last">
    								<xsl:text> </xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/Note"/>
    								<xsl:text>:</xsl:text>
    							</td>
    							<td class="images">
    								<xsl:value-of select="HomeTalk/SpeakerNotes" disable-output-escaping="yes"/>
    							</td>
    						</tr>
    
    					</table>
                    </div>

                    <div class="section">
    					<div class="content">
    						<h2>
    							<xsl:text>Next Week</xsl:text>
    						</h2>
    						<p class="nextweek">
    							<xsl:variable name="week" select="../Date/@NextWeek"/>
    							<xsl:value-of select="$AssignHistory/AssignmentHistory/*[name()=$week]/PublicTalkInfo/PublicTalkTheme"/>
    						</p>
    					</div>
    
    					<div class="content">
    						<h2>
    							<xsl:value-of select="//Labels/PTS_WTStudy"/>
    						</h2>
    					</div>
    					<table class="table1">
    						<colgroup>
    							<col class="colTime"/>
    							<col class="colLabel"/>
    							<col class="colText"/>
    						</colgroup>
    						<tr>
    							<td>
    								<xsl:value-of select="SongInfo/SongMiddle/@StartTime24"/>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/Song"/>
    								<xsl:text>:</xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="SongInfo/SongMiddle/@Title"/>
    								<xsl:text> (#</xsl:text>
    								<xsl:value-of select="SongInfo/SongMiddle"/>
    								<xsl:text>)</xsl:text>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank first">
    								<xsl:value-of select="WatchtowerStudy/Time/@StartTime24"/>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/PTS_Theme"/>
    								<xsl:text>:</xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="Assignments/WatchtowerStudy/Theme"/>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank">
    								<xsl:text> </xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/PTS_WTConductor"/>
    								<xsl:text>: </xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="Assignments/Conductor"/>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank last">
    								<xsl:text> </xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/PTS_WTReader"/>
    								<xsl:text>: </xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="Assignments/Reader"/>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank first">
    								<xsl:value-of select="SongInfo/SongEnd/@StartTime24"/>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/Song"/>
    								<xsl:text>:</xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="SongInfo/SongEnd/@Title"/>
    								<xsl:text> (#</xsl:text>
    								<xsl:value-of select="SongInfo/SongEnd"/>
    								<xsl:text>)</xsl:text>
    							</td>
    						</tr>
    						<tr>
    							<td class="blank last">
    								<xsl:text> </xsl:text>
    							</td>
    							<td>
    								<xsl:value-of select="//Labels/Prayer"/>
    							</td>
    							<td>
    								<xsl:value-of select="Assignments/PrayerClose"/>
    							</td>
    						</tr>
    
    					</table>
                    </div>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="PageBreak">
		<div style="page-break-before: always"/>
	</xsl:template>


</xsl:stylesheet>